Page 16 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 16

Home

    silence or secrecy imposed by initiation into religious
    rites. The root word #6 (Muo) means to shut the
    mouth. A good interpretation would be Secret Babylon.
    What is inferred here is that secret organizations would
    accumulate enough power to rule over the rulers of the
    world and at the same time keep their control hidden

    ce owes

    from public view. Ancient Babylon ruled openly, Mystery
    Babylon rules secretly. The name of Babylon was
    probably given to this center of world power because
    of its similarities to Ancient Babylon. Following is a list

    And saying, Alas, alas, that great city, that was
    clothed in fine linen, and purple, and scarlet, and decked
    with gold, and precious stones, and pearls!

    Revelation 18:16

    For in one hour so great riches is come to nought.
    Revelation 18:17

    11

    Mystery Babylon

    of those similarities.

    1. Both ruled the world:

    And the woman which thou sawest is that great city,

    which reigneth over the kings of the earth.

    Revelation 17:18

    2. Both were exceedingly rich:

    3. Both receive a prophecy of judgement: